#!/bin/bash

# Result:
#         out/Bootstrap               -  signed kernel prepared for bootloader partition
#         out/uImzlib_null_magNNN.img -  image for kernel partition
#         out/uImzlib_magNNN.img      -  signed image for rootfs included in imageupdate archive
#

R='\033[1;31m'  # RED
G='\033[0;32m'  # GREEN
Y='\033[0;33m'  # YELLOW
CL='\E[0m'      # End color


if [[ $# < 2 ]]; then
    echo -e ""
    echo -e $Y"Usage:"$CL
    echo -e $Y"    $0 <model_name> <path_to_kernel> <profile>"$CL
    echo -e ""
    echo -e $Y"    The <model_name> should be the same as the Model Name of STB"$CL
    echo -e $Y"    The Model Name can be viewed in System Recovery Utility > Device Information > Model"$CL
    echo -e $Y"    or in System Settings > Device Info > Model"$CL
    echo -e ""
    echo -e $Y"For example:"$CL
    echo -e $Y"    $0 MAG420 ./mag420/images/uImage_mag420.clean img_make.profile.mag420"$CL
    echo -e ""
    exit 0
fi

MODEL=$1
SOURCE=$2

if [ "$3" != "" ]; then
  . $3
fi

rm -rf ./${MODEL,,}/out/*

mkdir -p ./${MODEL,,}/out

cp -vf ${SOURCE} ./${MODEL,,}/out/uImage_${MODEL,,}.clean

if [ "$MAKE_CUSTOM_IMAGE" != "" ] ; then
    OLD_KEY=$MAG200_OP_KEY
    export MAG200_OP_KEY=STB_PUBLIC
    ./mksign.sh ./${MODEL,,}/images/uImage_${MODEL,,}.clean ./${MODEL,,}/out/uImage_${MODEL,,} SHA256
    export MAG200_OP_KEY=$OLD_KEY
else
    ./mksign.sh ./${MODEL,,}/out/uImage_${MODEL,,}.clean ./${MODEL,,}/out/uImage_${MODEL,,} SHA256
fi

if [ "$KERNEL_FS_TYPE" == "ubi" ]; then
    ./mk_kfs.sh ./${MODEL,,}/out/uImage_${MODEL,,} ./${MODEL,,}/out/uImzlib_null_${MODEL,,}.img
elif [ "$KERNEL_FS_TYPE" == "raw324" ]; then
    ./writebb_util -o ./${MODEL,,}/out/uImzlib_null_${MODEL,,}.img ./${MODEL,,}/out/uImage_${MODEL,,}
else
    cp ./${MODEL,,}/out/uImage_${MODEL,,} ./${MODEL,,}/out/uImzlib_null_${MODEL,,}.img
fi

cp ./${MODEL,,}/out/uImage_${MODEL,,} ./${MODEL,,}/out/Bootstrap

./mksign.sh ./${MODEL,,}/out/uImzlib_null_${MODEL,,}.img ./${MODEL,,}/out/uImzlib_${MODEL,,}.img SHA256

tput sgr0
